aboutsummaryrefslogtreecommitdiff
path: root/bin/ed/re.c
diff options
context:
space:
mode:
authorAndrew Moore <alm@FreeBSD.org>1994-02-01 00:36:28 +0000
committerAndrew Moore <alm@FreeBSD.org>1994-02-01 00:36:28 +0000
commit95e6217e73cb4eb3a08a0a855ec59924805beb1b (patch)
treec82867e2169de15c590a9d6a1c65adf6483131e8 /bin/ed/re.c
parenta301c9d5d4f25e97f8a55759ed77fed00fac8ca9 (diff)
downloadsrc-95e6217e73cb4eb3a08a0a855ec59924805beb1b.tar.gz
src-95e6217e73cb4eb3a08a0a855ec59924805beb1b.zip
Fixed range address bug: 1,2, == 2,2 not 2,.
Overhauled the name space, reworked some modules and removed the obsolescent Addison-Wesley copyright.
Notes
Notes: svn path=/head/; revision=1057
Diffstat (limited to 'bin/ed/re.c')
-rw-r--r--bin/ed/re.c67
1 files changed, 26 insertions, 41 deletions
diff --git a/bin/ed/re.c b/bin/ed/re.c
index 7553d5f2e332..d0d4e6c0e20b 100644
--- a/bin/ed/re.c
+++ b/bin/ed/re.c
@@ -1,12 +1,9 @@
/* re.c: This file contains the regular expression interface routines for
the ed line editor. */
/*-
- * Copyright (c) 1993 The Regents of the University of California.
+ * Copyright (c) 1993 Andrew Moore, Talke Studio.
* All rights reserved.
*
- * This code is derived from software contributed to Berkeley
- * by Andrew Moore, Talke Studio.
- *
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
@@ -15,18 +12,11 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- * must display the following acknowledgement:
- * This product includes software developed by the University of
- * California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
- * may be used to endorse or promote products derived from this software
- * without specific prior written permission.
*
- * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
* FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
* OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
@@ -37,40 +27,34 @@
*/
#ifndef lint
-static char sccsid[] = "@(#)re.c 5.5 (Berkeley) 3/28/93";
+static char *rcsid = "@(#)$Id: re.c,v 1.2 1993/12/14 16:19:56 alm Exp $";
#endif /* not lint */
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
#include "ed.h"
-extern char *lhbuf;
-extern int lhbufsz;
-extern char *ibufp;
-extern int ibufsz;
+
extern int patlock;
-char errmsg[MAXFNAME + 40] = "";
+char errmsg[MAXPATHLEN + 40] = "";
-/* optpat: return pointer to compiled pattern from command buffer */
+/* get_compiled_pattern: return pointer to compiled pattern from command
+ buffer */
pattern_t *
-optpat()
+get_compiled_pattern()
{
static pattern_t *exp = NULL;
char *exps;
- char delim;
+ char delimiter;
int n;
- if ((delim = *ibufp) == ' ') {
+ if ((delimiter = *ibufp) == ' ') {
sprintf(errmsg, "invalid pattern delimiter");
return NULL;
- } else if (delim == '\n' || *++ibufp == '\n' || *ibufp == delim) {
+ } else if (delimiter == '\n' || *++ibufp == '\n' || *ibufp == delimiter) {
if (!exp) sprintf(errmsg, "no previous pattern");
return exp;
- } else if ((exps = getlhs(delim)) == NULL)
+ } else if ((exps = extract_pattern(delimiter)) == NULL)
return NULL;
/* buffer alloc'd && not reserved */
if (exp && !patlock)
@@ -90,23 +74,24 @@ optpat()
}
-extern int isbinary;
-
-/* getlhs: copy a pattern string from the command buffer; return pointer
- to the copy */
+/* extract_pattern: copy a pattern string from the command buffer; return
+ pointer to the copy */
char *
-getlhs(delim)
- int delim;
+extract_pattern(delimiter)
+ int delimiter;
{
+ static char *lhbuf = NULL; /* buffer */
+ static int lhbufsz = 0; /* buffer size */
+
char *nd;
int len;
- for (nd = ibufp; *nd != delim && *nd != '\n'; nd++)
+ for (nd = ibufp; *nd != delimiter && *nd != '\n'; nd++)
switch (*nd) {
default:
break;
case '[':
- if ((nd = ccl(++nd)) == NULL) {
+ if ((nd = parse_char_class(++nd)) == NULL) {
sprintf(errmsg, "unbalanced brackets ([])");
return NULL;
}
@@ -119,17 +104,17 @@ getlhs(delim)
break;
}
len = nd - ibufp;
- CKBUF(lhbuf, lhbufsz, len + 1, NULL);
+ REALLOC(lhbuf, lhbufsz, len + 1, NULL);
memcpy(lhbuf, ibufp, len);
lhbuf[len] = '\0';
ibufp = nd;
- return (isbinary) ? nultonl(lhbuf, len) : lhbuf;
+ return (isbinary) ? NUL_TO_NEWLINE(lhbuf, len) : lhbuf;
}
/* ccl: expand a POSIX character class */
char *
-ccl(s)
+parse_char_class(s)
char *s;
{
int c, d;
@@ -119,17 +104,17 @@ getlhs(delim)
}
-/* ccl: expand a POSIX character class */
+/* parse_char_class: expand a POSIX character class */
char *